Index — SoL 3 user manual

# Index

B | C | D | F | G | H | I | L | M | N | O | P | Q | R | S | T | U | W

## B

Black Slam Board | Bounties Break

## C

C/B C/m Cannon Championship Insert and edit Championships Management | Chief Referee Club Insert and edit Clubs Management, [1] Competitors fixup Tourneys Covering

## D

Due

## F

Finger | Finish

## G

glicko ratings

## H

Hand

## I

Imaginary lines Improper | Insert and edit Championship Club Rating Tourney

## L

Laws

## M

Management Championships Clubs, [1] Players

## N

National federations

## O

Opponent in Doubles | Opponent in Singles

## P

Pair Penalty Phantom Placing Player | Players Management Rates Pocketing Proper Push

## Q

Queen

## R

Rates Players Rating Insert and edit | ratings glicko

## S

Shot | Stroke

## T

Thumbing Tourney Insert and edit | Tourneys Competitors fixup Turn

## U

Umpire

## W

White Slam